require 'net/http'
require 'uri'

module CcbConnectClient

  module Service

    def self.refund refund_request
      refund_response = RefundResponse.new
      Handler.new.response_handler refund_request, refund_response
    end

    def self.payment_details_query payment_details_query_request
      payment_details_query_response = PaymentDetailsQueryResponse.new
      Handler.new.response_handler payment_details_query_request, payment_details_query_response
    end

    class Handler

      def response_handler(request, response)
        res = http_post_form CcbConnectClient.server, request.to_xml
        doc = Document.new(res.body)

        if doc.elements["TX/RETURN_CODE"].text != "000000"
          result = BaseResponse.from_xml res.body
          result.successful = false
        else
          result = response.from_xml res.body
          result.successful = true
        end
        result
      end

      private

      def http_post_form(url, xml)
        uri = URI.parse(url)
        req = Net::HTTP::Post.new(uri)
        req["Content-Type"] = "application/x-www-form-urlencoded"
        # We don't accpet gzip encoding since the http.request method will raise the EOF error
        req["Accept-Encoding"] = "identity"
        res = Net::HTTP.start(uri.host, uri.port, :use_ssl => uri.scheme == 'https') do |http|
          if CcbConnectClient.debug_mode && CcbConnectClient.logger
            CcbConnectClient.logger.debug("CCB Connect requset xml : #{xml}")
          end
          req.set_form_data('requestXml' => xml)
          http.request req
        end
        if CcbConnectClient.debug_mode && CcbConnectClient.logger
          CcbConnectClient.logger.debug("CCB Connect response: #{res.body}")
        end
        res
      end

    end
  end
end
